@@ -28,7 +28,6 @@
 #'
 #' @concept object_conversion
 #'
-#' @import cli
 #' @import Seurat
 #' @importFrom dplyr left_join join_by select any_of
 #' @importFrom magrittr "%>%"
@@ -248,7 +247,6 @@ as.LIGER.Seurat <- function(
 #'
 #' @concept object_conversion
 #'
-#' @import cli
 #' @import Seurat
 #' @importFrom dplyr left_join join_by select any_of bind_rows union intersect
 #' @importFrom magrittr "%>%"
@@ -495,7 +493,6 @@ as.LIGER.list <- function(
 #'
 #' @concept object_conversion
 #'
-#' @import cli
 #' @import Matrix
 #' @import Seurat
 #' @importFrom dplyr any_of pull select
@@ -699,244 +696,243 @@ as.Seurat.liger <- function(
 }
 
 
-#' Create a Seurat object containing the data from a liger object `r lifecycle::badge("soft-deprecated")`
-#'
-#' Merges raw.data and scale.data of object, and creates Seurat object with these values along with
-#' tsne.coords, iNMF factorization, and cluster assignments. Supports Seurat V2 and V3.
-#'
-#' Stores original dataset identity by default in new object metadata if dataset names are passed
-#' in nms. iNMF factorization is stored in dim.reduction object with key "iNMF".
-#'
-#' @param liger_object \code{liger} object.
-#' @param nms By default, labels cell names with dataset of origin (this is to account for cells in
-#' different datasets which may have same name). Other names can be passed here as vector, must have
-#' same length as the number of datasets. (default names(H)).
-#' @param renormalize Whether to log-normalize raw data using Seurat defaults (default TRUE).
-#' @param use.liger.genes Whether to carry over variable genes (default TRUE).
-#' @param by.dataset Include dataset of origin in cluster identity in Seurat object (default FALSE).
-#' @param keep_meta logical. Whether to transfer additional metadata (nGene/nUMI/dataset already transferred)
-#' to new Seurat Object.  Default is TRUE.
-#' @param reduction_label Name of dimensionality reduction technique used.  Enables accurate transfer
-#' or name to Seurat object instead of defaulting to "tSNE".
-#' @param seurat_assay Name to set for assay in Seurat Object.  Default is "RNA".
-#' @param assay_type what type of Seurat assay to create in new object (Assay vs Assay5).
-#' Default is NULL which will default to the current user settings.
-#' See \code{\link{Convert_Assay}} parameter `convert_to` for acceptable values.
-#' @param add_barcode_names logical, whether to add dataset names to the cell barcodes when
-#' creating Seurat object, default is FALSE.
-#' @param barcode_prefix logical, if `add_barcode_names = TRUE` should the names be added as
-#' prefix to current cell barcodes/names or a suffix (default is TRUE; prefix).
-#' @param barcode_cell_id_delimiter The delimiter to use when adding dataset id to barcode
-#' prefix/suffix.  Default is "_".
-#'
-#' @return Seurat object with raw.data, scale.data, reduction_label, iNMF, and ident slots set.
-#'
-#' @references Original function is part of LIGER package \url{https://github.com/welch-lab/liger} (Licence: GPL-3).
-#' Function was slightly modified for use in scCustomize with keep.meta parameter.  Also posted as
-#' PR to liger GitHub.
-#'
-#' @import cli
-#' @import Matrix
-#' @importFrom dplyr any_of pull select
-#' @importFrom magrittr "%>%"
-#' @importFrom methods as new
-#' @importFrom utils packageVersion
-#'
-#' @export
-#'
-#' @concept object_conversion
-#'
-#' @examples
-#' \dontrun{
-#' seurat_object <- Liger_to_Seurat(liger_object = LIGER_OBJ, reduction_label = "UMAP")
-#' }
+# Create a Seurat object containing the data from a liger object `r lifecycle::badge("soft-deprecated")`
+#
+# Merges raw.data and scale.data of object, and creates Seurat object with these values along with
+# tsne.coords, iNMF factorization, and cluster assignments. Supports Seurat V2 and V3.
+#
+# Stores original dataset identity by default in new object metadata if dataset names are passed
+# in nms. iNMF factorization is stored in dim.reduction object with key "iNMF".
+#
+# @param liger_object \code{liger} object.
+# @param nms By default, labels cell names with dataset of origin (this is to account for cells in
+# different datasets which may have same name). Other names can be passed here as vector, must have
+# same length as the number of datasets. (default names(H)).
+# @param renormalize Whether to log-normalize raw data using Seurat defaults (default TRUE).
+# @param use.liger.genes Whether to carry over variable genes (default TRUE).
+# @param by.dataset Include dataset of origin in cluster identity in Seurat object (default FALSE).
+# @param keep_meta logical. Whether to transfer additional metadata (nGene/nUMI/dataset already transferred)
+# to new Seurat Object.  Default is TRUE.
+# @param reduction_label Name of dimensionality reduction technique used.  Enables accurate transfer
+# or name to Seurat object instead of defaulting to "tSNE".
+# @param seurat_assay Name to set for assay in Seurat Object.  Default is "RNA".
+# @param assay_type what type of Seurat assay to create in new object (Assay vs Assay5).
+# Default is NULL which will default to the current user settings.
+# See \code{\link{Convert_Assay}} parameter `convert_to` for acceptable values.
+# @param add_barcode_names logical, whether to add dataset names to the cell barcodes when
+# creating Seurat object, default is FALSE.
+# @param barcode_prefix logical, if `add_barcode_names = TRUE` should the names be added as
+# prefix to current cell barcodes/names or a suffix (default is TRUE; prefix).
+# @param barcode_cell_id_delimiter The delimiter to use when adding dataset id to barcode
+# prefix/suffix.  Default is "_".
+#
+# @return Seurat object with raw.data, scale.data, reduction_label, iNMF, and ident slots set.
+#
+# @references Original function is part of LIGER package \url{https://github.com/welch-lab/liger} (Licence: GPL-3).
+# Function was slightly modified for use in scCustomize with keep.meta parameter.  Also posted as
+# PR to liger GitHub.
+#
+# @import Matrix
+# @importFrom dplyr any_of pull select
+# @importFrom magrittr "%>%"
+# @importFrom methods as new
+# @importFrom utils packageVersion
+#
+# @export
+#
+# @concept object_conversion
+#
+# @examples
+# \dontrun{
+# seurat_object <- Liger_to_Seurat(liger_object = LIGER_OBJ, reduction_label = "UMAP")
+# }
 
-Liger_to_Seurat <- function(
-    liger_object,
-    nms = names(liger_object@H),
-    renormalize = TRUE,
-    use.liger.genes = TRUE,
-    by.dataset = FALSE,
-    keep_meta = TRUE,
-    reduction_label = "UMAP",
-    seurat_assay = "RNA",
-    assay_type = NULL,
-    add_barcode_names = FALSE,
-    barcode_prefix = TRUE,
-    barcode_cell_id_delimiter = "_"
-) {
-  deprecate_soft(when = "2.1.0",
-                            what = "Liger_to_Seurat()",
-                            with = "as.Seurat()",
-                            details = c("i" = "Please adjust code now to prepare for full deprecation.")
-  )
-
-
-
-  if (is.null(x = reduction_label)) {
-    cli_abort(message = c("{.code reduction_label} parameter was not set.",
-                          "*" = "LIGER objects do not store name of dimensionality reduction technique used.",
-                          "i" = "In order to retain proper labels in Seurat object please set {.code reduction_label} to {.val tSNE}, {.val UMAP}, {.val etc}."))
-  }
-
-  # Adjust name for dimreduc key
-  key_name <- paste0(reduction_label, "_")
-
-  # adjust raw data slot if needed
-  if (!inherits(x = liger_object@raw.data[[1]], what = "dgCMatrix")) {
-    liger_object@raw.data <- lapply(liger_object@raw.data, as, Class = "CsparseMatrix")
-  }
-
-  # check assay_type is ok
-  if (!is.null(x = assay_type)) {
-    # Check accepted
-    accepted_V3 <- c("Assay", "assay", "V3", "v3")
-    accepted_V5 <- c("Assay5", "assay5", "V5", "v5")
-
-    if (!convert_to %in% c(accepted_V5, accepted_V3)) {
-      cli_abort(message = c("Value provided to {.code convert_to} ({.field {convert_to}}) was not accepted value.",
-                            "i" = "Accepted values to convert to V3/4 are: {.field {accepted_V3}}",
-                            "i" = "Accepted values to convert to V5 are: {.field {accepted_V5}}"))
-    }
-
-    # set assay value
-    if (convert_to %in% accepted_V5) {
-      if (packageVersion(pkg = "Seurat") < "5") {
-        cli_abort(message = "Seurat version must be v5.0.0 or greater to create To create Assay5.")
-      }
-
-      convert_to <- "v5"
-    }
-
-    if (convert_to %in% accepted_V3) {
-      convert_to <- "v3"
-    }
-  }
-
-  # merge raw data
-  if (isTRUE(x = add_barcode_names)) {
-    raw.data <- Merge_Sparse_Data_All(matrix_list = liger_object@raw.data, add_cell_ids = nms, prefix = barcode_prefix, cell_id_delimiter = barcode_cell_id_delimiter)
-  } else {
-    raw.data <- Merge_Sparse_Data_All(matrix_list = liger_object@raw.data)
-  }
-
-  # create object
-  new.seurat <- CreateSeuratObject(counts = raw.data, assay = seurat_assay)
-
-  # normalize data
-  if (isTRUE(x = renormalize)) {
-    new.seurat <- Seurat::NormalizeData(new.seurat)
-  } else {
-    if (length(x = liger_object@norm.data) > 0) {
-      if (isTRUE(x = add_barcode_names)) {
-        norm.data <- Merge_Sparse_Data_All(matrix_list = liger_object@norm.data, add_cell_ids = nms, prefix = barcode_prefix, cell_id_delimiter = barcode_cell_id_delimiter)
-      } else {
-        norm.data <- Merge_Sparse_Data_All(matrix_list = liger_object@norm.data)
-      }
-
-      new.seurat <- SetAssayData(object = new.seurat, layer = "data", slot = "data", new.data = norm.data)
-    }
-  }
-
-  if (length(x = liger_object@var.genes) > 0 && isTRUE(x = use.liger.genes)) {
-    VariableFeatures(object = new.seurat) <- liger_object@var.genes
-  }
-  if (length(x = liger_object@scale.data) > 0) {
-    scale.data <- t(x = Reduce(rbind, liger_object@scale.data))
-    colnames(x = scale.data) <- colnames(x = raw.data)
-    new.seurat <- SetAssayData(object = new.seurat, layer = "scale.data", slot = "scale.data", new.data = scale.data)
-  }
-
-
-  if (all(dim(x = liger_object@W) > 0) && all(dim(x = liger_object@H.norm) > 0)) {
-    inmf.loadings <- t(x = liger_object@W)
-    rinmf.loadings <- inmf.loadings
-
-    dimnames(x = inmf.loadings) <- list(liger_object@var.genes,
-                                        paste0("iNMF_", seq_len(ncol(inmf.loadings))))
-    dimnames(x = rinmf.loadings) <- list(liger_object@var.genes,
-                                         paste0("rawiNMF_", seq_len(ncol(rinmf.loadings))))
-
-    inmf.embeddings <- liger_object@H.norm
-    rinmf.embeddings <- do.call(what = "rbind", args = liger_object@H)
-
-    dimnames(x = inmf.embeddings) <- list(unlist(x = lapply(liger_object@scale.data, rownames), use.names = FALSE),
-                                          paste0("iNMF_", seq_len(ncol(inmf.loadings))))
-    dimnames(x = rinmf.embeddings) <- list(unlist(x = lapply(liger_object@scale.data, rownames), use.names = FALSE),
-                                           paste0("rawiNMF_", seq_len(ncol(x = inmf.loadings))))
-
-
-    inmf.obj <- CreateDimReducObject(
-      embeddings = inmf.embeddings,
-      loadings = inmf.embeddings,
-      assay = seurat_assay,
-      global = TRUE,
-      key = "iNMF_"
-    )
-    new.seurat[["iNMF"]] <- inmf.obj
-
-    rinmf.obj <- CreateDimReducObject(
-      embeddings = rinmf.embeddings,
-      loadings = rinmf.loadings,
-      key = "rawiNMF_",
-      global = TRUE,
-      assay = seurat_assay
-    )
-  }
-
-
-  if (all(dim(x = liger_object@tsne.coords) > 0)) {
-    dimreduc.embeddings <- liger_object@tsne.coords
-    dimnames(x = dimreduc.embeddings) <- list(rownames(liger_object@H.norm),
-                                              paste0(key_name, 1:2))
-
-    dimreduc.obj <- CreateDimReducObject(
-      embeddings = dimreduc.embeddings,
-      assay = seurat_assay,
-      global = TRUE,
-      key = key_name
-    )
-    new.seurat[[reduction_label]] <- dimreduc.obj
-  }
-
-  new.seurat$orig.ident <- liger_object@cell.data$dataset
-
-  idents <- liger_object@clusters
-
-  if (length(x = idents) == 0 || isTRUE(x = by.dataset)) idents <- liger_object@cell.data$dataset
-  Idents(object = new.seurat) <- idents
-
-  # transfer meta
-  if (isTRUE(x = keep_meta)) {
-    # extract meta data from liger object
-    liger_meta <- Fetch_Meta(object = liger_object)
-    # remove meta data values already transferred
-    liger_meta <- liger_meta %>%
-      select(-any_of(c("nUMI", "nGene", "dataset")))
-    # extract meta data names
-    meta_names <- colnames(x = liger_meta)
-    # add meta data to new seurat object
-    for (meta_var in meta_names){
-      meta_transfer <- liger_meta %>%
-        pull(meta_var)
-      names(x = meta_transfer) <- colnames(x = new.seurat)
-      new.seurat <- AddMetaData(object = new.seurat,
-                                metadata = meta_transfer,
-                                col.name = meta_var)
-    }
-  }
-
-
-  if (!is.null(x = assay_type)) {
-    options_list <- options()
-    if (options_list$Seurat.object.assay.version != convert_to) {
-      new.seurat <- Convert_Assay(seurat_object = new.seurat, convert_to = convert_to)
-    }
-  }
-
-  # return object
-  return(new.seurat)
-}
+# Liger_to_Seurat <- function(
+#     liger_object,
+#     nms = names(liger_object@H),
+#     renormalize = TRUE,
+#     use.liger.genes = TRUE,
+#     by.dataset = FALSE,
+#     keep_meta = TRUE,
+#     reduction_label = "UMAP",
+#     seurat_assay = "RNA",
+#     assay_type = NULL,
+#     add_barcode_names = FALSE,
+#     barcode_prefix = TRUE,
+#     barcode_cell_id_delimiter = "_"
+# ) {
+#   deprecate_soft(when = "2.1.0",
+#                             what = "Liger_to_Seurat()",
+#                             with = "as.Seurat()",
+#                             details = c("i" = "Please adjust code now to prepare for full deprecation.")
+#   )
+#
+#
+#
+#   if (is.null(x = reduction_label)) {
+#     cli_abort(message = c("{.code reduction_label} parameter was not set.",
+#                           "*" = "LIGER objects do not store name of dimensionality reduction technique used.",
+#                           "i" = "In order to retain proper labels in Seurat object please set {.code reduction_label} to {.val tSNE}, {.val UMAP}, {.val etc}."))
+#   }
+#
+#   # Adjust name for dimreduc key
+#   key_name <- paste0(reduction_label, "_")
+#
+#   # adjust raw data slot if needed
+#   if (!inherits(x = liger_object@raw.data[[1]], what = "dgCMatrix")) {
+#     liger_object@raw.data <- lapply(liger_object@raw.data, as, Class = "CsparseMatrix")
+#   }
+#
+#   # check assay_type is ok
+#   if (!is.null(x = assay_type)) {
+#     # Check accepted
+#     accepted_V3 <- c("Assay", "assay", "V3", "v3")
+#     accepted_V5 <- c("Assay5", "assay5", "V5", "v5")
+#
+#     if (!convert_to %in% c(accepted_V5, accepted_V3)) {
+#       cli_abort(message = c("Value provided to {.code convert_to} ({.field {convert_to}}) was not accepted value.",
+#                             "i" = "Accepted values to convert to V3/4 are: {.field {accepted_V3}}",
+#                             "i" = "Accepted values to convert to V5 are: {.field {accepted_V5}}"))
+#     }
+#
+#     # set assay value
+#     if (convert_to %in% accepted_V5) {
+#       if (packageVersion(pkg = "Seurat") < "5") {
+#         cli_abort(message = "Seurat version must be v5.0.0 or greater to create To create Assay5.")
+#       }
+#
+#       convert_to <- "v5"
+#     }
+#
+#     if (convert_to %in% accepted_V3) {
+#       convert_to <- "v3"
+#     }
+#   }
+#
+#   # merge raw data
+#   if (isTRUE(x = add_barcode_names)) {
+#     raw.data <- Merge_Sparse_Data_All(matrix_list = liger_object@raw.data, add_cell_ids = nms, prefix = barcode_prefix, cell_id_delimiter = barcode_cell_id_delimiter)
+#   } else {
+#     raw.data <- Merge_Sparse_Data_All(matrix_list = liger_object@raw.data)
+#   }
+#
+#   # create object
+#   new.seurat <- CreateSeuratObject(counts = raw.data, assay = seurat_assay)
+#
+#   # normalize data
+#   if (isTRUE(x = renormalize)) {
+#     new.seurat <- Seurat::NormalizeData(new.seurat)
+#   } else {
+#     if (length(x = liger_object@norm.data) > 0) {
+#       if (isTRUE(x = add_barcode_names)) {
+#         norm.data <- Merge_Sparse_Data_All(matrix_list = liger_object@norm.data, add_cell_ids = nms, prefix = barcode_prefix, cell_id_delimiter = barcode_cell_id_delimiter)
+#       } else {
+#         norm.data <- Merge_Sparse_Data_All(matrix_list = liger_object@norm.data)
+#       }
+#
+#       new.seurat <- SetAssayData(object = new.seurat, layer = "data", slot = "data", new.data = norm.data)
+#     }
+#   }
+#
+#   if (length(x = liger_object@var.genes) > 0 && isTRUE(x = use.liger.genes)) {
+#     VariableFeatures(object = new.seurat) <- liger_object@var.genes
+#   }
+#   if (length(x = liger_object@scale.data) > 0) {
+#     scale.data <- t(x = Reduce(rbind, liger_object@scale.data))
+#     colnames(x = scale.data) <- colnames(x = raw.data)
+#     new.seurat <- SetAssayData(object = new.seurat, layer = "scale.data", slot = "scale.data", new.data = scale.data)
+#   }
+#
+#
+#   if (all(dim(x = liger_object@W) > 0) && all(dim(x = liger_object@H.norm) > 0)) {
+#     inmf.loadings <- t(x = liger_object@W)
+#     rinmf.loadings <- inmf.loadings
+#
+#     dimnames(x = inmf.loadings) <- list(liger_object@var.genes,
+#                                         paste0("iNMF_", seq_len(ncol(inmf.loadings))))
+#     dimnames(x = rinmf.loadings) <- list(liger_object@var.genes,
+#                                          paste0("rawiNMF_", seq_len(ncol(rinmf.loadings))))
+#
+#     inmf.embeddings <- liger_object@H.norm
+#     rinmf.embeddings <- do.call(what = "rbind", args = liger_object@H)
+#
+#     dimnames(x = inmf.embeddings) <- list(unlist(x = lapply(liger_object@scale.data, rownames), use.names = FALSE),
+#                                           paste0("iNMF_", seq_len(ncol(inmf.loadings))))
+#     dimnames(x = rinmf.embeddings) <- list(unlist(x = lapply(liger_object@scale.data, rownames), use.names = FALSE),
+#                                            paste0("rawiNMF_", seq_len(ncol(x = inmf.loadings))))
+#
+#
+#     inmf.obj <- CreateDimReducObject(
+#       embeddings = inmf.embeddings,
+#       loadings = inmf.embeddings,
+#       assay = seurat_assay,
+#       global = TRUE,
+#       key = "iNMF_"
+#     )
+#     new.seurat[["iNMF"]] <- inmf.obj
+#
+#     rinmf.obj <- CreateDimReducObject(
+#       embeddings = rinmf.embeddings,
+#       loadings = rinmf.loadings,
+#       key = "rawiNMF_",
+#       global = TRUE,
+#       assay = seurat_assay
+#     )
+#   }
+#
+#
+#   if (all(dim(x = liger_object@tsne.coords) > 0)) {
+#     dimreduc.embeddings <- liger_object@tsne.coords
+#     dimnames(x = dimreduc.embeddings) <- list(rownames(liger_object@H.norm),
+#                                               paste0(key_name, 1:2))
+#
+#     dimreduc.obj <- CreateDimReducObject(
+#       embeddings = dimreduc.embeddings,
+#       assay = seurat_assay,
+#       global = TRUE,
+#       key = key_name
+#     )
+#     new.seurat[[reduction_label]] <- dimreduc.obj
+#   }
+#
+#   new.seurat$orig.ident <- liger_object@cell.data$dataset
+#
+#   idents <- liger_object@clusters
+#
+#   if (length(x = idents) == 0 || isTRUE(x = by.dataset)) idents <- liger_object@cell.data$dataset
+#   Idents(object = new.seurat) <- idents
+#
+#   # transfer meta
+#   if (isTRUE(x = keep_meta)) {
+#     # extract meta data from liger object
+#     liger_meta <- Fetch_Meta(object = liger_object)
+#     # remove meta data values already transferred
+#     liger_meta <- liger_meta %>%
+#       select(-any_of(c("nUMI", "nGene", "dataset")))
+#     # extract meta data names
+#     meta_names <- colnames(x = liger_meta)
+#     # add meta data to new seurat object
+#     for (meta_var in meta_names){
+#       meta_transfer <- liger_meta %>%
+#         pull(meta_var)
+#       names(x = meta_transfer) <- colnames(x = new.seurat)
+#       new.seurat <- AddMetaData(object = new.seurat,
+#                                 metadata = meta_transfer,
+#                                 col.name = meta_var)
+#     }
+#   }
+#
+#
+#   if (!is.null(x = assay_type)) {
+#     options_list <- options()
+#     if (options_list$Seurat.object.assay.version != convert_to) {
+#       new.seurat <- Convert_Assay(seurat_object = new.seurat, convert_to = convert_to)
+#     }
+#   }
+#
+#   # return object
+#   return(new.seurat)
+# }
 
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -962,7 +958,6 @@ Liger_to_Seurat <- function(
 #'
 #' @concept object_conversion
 #'
-#' @import cli
 #' @import Seurat
 #' @importFrom stringr str_to_lower
 #'
@@ -1175,7 +1170,6 @@ as.anndata.Seurat <- function(
 #'
 #' @concept object_conversion
 #'
-#' @import cli
 #' @importFrom dplyr mutate
 #' @importFrom magrittr "%>%"
 #' @importFrom stringr str_to_lower
@@ -1410,7 +1404,6 @@ as.anndata.liger <- function(
 #'
 #' @concept object_conversion
 #'
-#' @import cli
 #' @importFrom dplyr mutate
 #' @importFrom magrittr "%>%"
 #' @importFrom stringr str_to_lower
@@ -1540,8 +1533,6 @@ Convert_Assay <- function(
 #'
 #' @concept object_conversion
 #'
-#' @import cli
-#'
 #' @export
 #'
 #' @examples
